@@ -38,7 +38,9 @@ class EnoException(Exception, ABC):
     result: CheckerTaskResult = CheckerTaskResult.CHECKER_TASK_RESULT_INTERNAL_ERROR
 
     def __init__(
-        self, message: Optional[str], internal_message: Optional[str] = None,
+        self,
+        message: Optional[str],
+        internal_message: Optional[str] = None,
     ):
         self.message: Optional[str] = message
         self.internal_message: Optional[str] = internal_message
